#!/bin/sh
#
# Protected by US patent 6,006,034; patents pending.
# Copyright 2022 Flexera Software LLC.
# Reproduction, adaptation, or translation without prior permission
# is prohibited.
#
#
# Get the main configuration
if [ -r "/etc/managesoft.ini" ]
then
	# Get the install directory
INSTALLDIR=`sed -n '/^InstallDir[ 	]*=/{
s/InstallDir[ 	]*=[ 	]*\([^ 	].*\)/\1/
s/\/*[ 	]*$//
p
q
}' '/etc/managesoft.ini'`

	# Get the managesoft data directory
COMMONAPPDATAFOLDER=`sed -n '/^CommonAppDataFolder[ 	]*=/{
s/CommonAppDataFolder[ 	]*=[ 	]*\([^ 	].*\)/\1/
s/\/*[ 	]*$//
p
q
}' '/etc/managesoft.ini'`

fi
if [ ! -d "$INSTALLDIR" ] || [ "$INSTALLDIR" = "/" ]
then
	echo "ERROR:   ManageSoft has not been configured or is not installed."
	echo "         Please make sure you have a /etc/managesoft.ini file with"
	echo "         the correct InstallDir set."
	exit 1
fi

if [ ! -w "/etc/managesoft.ini" ]
then
	echo "ERROR:   You do not have enough privileges to unconfigure ManageSoft."
	echo "         Please make sure you have logged in as root or use sudo to"
	echo "         become root."
	exit 1
fi

# Make sure we have a data directory destination to save old configuration
[ -z "$COMMONAPPDATAFOLDER" ] && COMMONAPPDATAFOLDER=/var/opt/managesoft
[ ! -d "$COMMONAPPDATAFOLDER/etc" ] && ( umask 077 && mkdir -p "$COMMONAPPDATAFOLDER/etc" )

#-----------------------------
# Stop and remove services
#-----------------------------
# Stop ManageSoft services for GNU/Linux
printf "Stopping ManageSoft services...\n"
[ -x /etc/init.d/ndtask -a -s /var/run/ndtask.pid ] && /etc/init.d/ndtask stop
[ -x /etc/init.d/mgsusageag -a -s /var/run/mgsusageag.pid ] && /etc/init.d/mgsusageag stop
[ -x /etc/init.d/fnms-docker-monitor -a -s /var/run/fnms-docker-monitor.pid ] && /etc/init.d/fnms-docker-monitor stop

# Remove ManageSoft services for Linux
printf "Removing service startup configuration: "
# Attempt removal with system tools
if [ -x /usr/sbin/update-rc.d ]
then
	[ -e /etc/init.d/ndtask ] && /usr/sbin/update-rc.d -f ndtask remove > /dev/null
	[ -e /etc/init.d/mgsusageag ] && /usr/sbin/update-rc.d -f mgsusageag remove > /dev/null
elif [ -x /sbin/insserv ]
then
	[ -e /etc/init.d/ndtask ] && /sbin/insserv -r ndtask
	[ -e /etc/init.d/mgsusageag ] && /sbin/insserv -r mgsusageag
elif [ -x /sbin/chkconfig ]
then
	[ -e /etc/init.d/ndtask ] && /sbin/chkconfig --del ndtask
	[ -e /etc/init.d/mgsusageag ] && /sbin/chkconfig --del mgsusageag
fi

# Make sure services are removed
rm -f /etc/rc?.d/*ndtask /etc/init.d/rc?.d/*ndtask
rm -f /etc/rc?.d/*mgsusageag /etc/init.d/rc?.d/*mgsusageag
echo "done"


#-----------------------------
# Wait for processes and save configuration
#-----------------------------
if [ -n "$INSTALLDIR" -a -x "$INSTALLDIR/bin/mgsconfig" ]
then

	if [ -n "$COMMONAPPDATAFOLDER" -a -d "$COMMONAPPDATAFOLDER/etc" ]
	then
		printf "Saving configuration: "
		"$INSTALLDIR/bin/mgsconfig" -e "$COMMONAPPDATAFOLDER/etc/config.save.ini"
		rm -f "$COMMONAPPDATAFOLDER/etc/config.ini"
		echo "Done"
	fi
fi

#-----------------------------
# Remove top level configuration
#-----------------------------
rm -f /etc/managesoft.ini

